@@ -17,10 +17,7 @@ import cv
 from util import exif
 import Guy
 
-from util.Notifier import Observable
-from util.Notifier import Observer
-
-class FaceMovie(object, Observable, Observer):
+class FaceMovie(object):
     '''
     Main class of the whole application. 
     Contains the core image processing functions.
@@ -39,8 +36,6 @@ class FaceMovie(object, Observable, Observer):
         :param face_param: the location of the profile file used to train the classifier
         :type face_param: string        
         """
-        Observable.__init__(self) # used to send notifications to process
-        Observer.__init__(self, "Library") # used to receive notification to stop
 
         self.console_logger = logging.getLogger('ConsoleLog') # Used to send messages to the console
         self.my_logger = logging.getLogger('FileLog') # Used to save events into a file
@@ -86,13 +81,6 @@ class FaceMovie(object, Observable, Observer):
 
         self.run = True # command used to stop the processing if needed
 
-    def update(self, message):
-        """
-        Used to receive system commands, using the Observer pattern
-        """
-        if len(message) == 1: # system command
-            self.run = False
-
     def list_guys(self):
         """
         Aims at populating the guys list, using the source folder as an input. 
@@ -111,13 +99,8 @@ class FaceMovie(object, Observable, Observer):
             sys.exit(0)
                 
         # loading images, create Guys and store it into guys
-        ptr = 0
         for root, _, files in os.walk(self.source):
             for a_file in files:
-                ptr += 1
-                # notifying the Observers
-                self.notify_progress("Processing file", ptr, len(files))
-
                 if self.run : # as long as we want to continue
                     guy_source = os.path.join(root, a_file)
                     try:
@@ -167,15 +150,9 @@ class FaceMovie(object, Observable, Observer):
         The Face of each guy is searched.
         In case no face is found, a warning is returned and Guy is set to None
         """
-        ptr = 0
         for a_guy in self.guys:
-            ptr += 1
             if self.run:
                 a_guy.search_face(self.face_params)
-
-                # notifying the Observers
-                self.notify_progress("Processing picture", ptr, self.number_guys())
-
                 if a_guy.has_face(): # face(s) have been found
                     self.console_logger.info("Face found for %s" % (a_guy.name))
                     self.my_logger.info("Face found for %s" % (a_guy.name))                
@@ -183,29 +160,6 @@ class FaceMovie(object, Observable, Observer):
                     self.console_logger.warning("No face found for %s. Skipped . . ." %(a_guy.name))
                     self.my_logger.warning("No face found for %s. Skipped . . ." %(a_guy.name))
         
-    def percent(self, num, den):
-        """
-        Returns a float between 0 and 1, being the percentage given by num / den
-        """
-        if num > den :
-            raise ArithmeticError
-        if den <= 0 : 
-            raise ZeroDivisionError
-
-        return (num / float(den))
-
-    def notify_progress(self, message_root, num, den):
-        """
-        A notification scheme to quickly notify most common messages
-        """
-        # notifying the Observers
-        try:
-            message = message_root + "  %d / %d" %(num, den)
-            self.notify([message, self.percent(num, den)])
-        except (ArithmeticError, ZeroDivisionError):
-            #pass
-            self.notify(["Error", 0])
-
     def clean_guys(self):
         """
         Removes all guys for who no face has been found.
@@ -230,6 +184,7 @@ class FaceMovie(object, Observable, Observer):
         self.check_depth()
 
         if self.number_guys() == 0:
+            print 
             self.console_logger.error("No face has been found in the whole repository! Exiting. . . ")
             self.my_logger.error("No face has been found in the whole repository! Exiting. . . ")            
             sys.exit(0) # FIXME : Find better way to do that
@@ -320,17 +275,11 @@ class FaceMovie(object, Observable, Observer):
         the image input image is placed in the output at the correct position.
         Black borders are set everywhere else.
         """
-        # TODO: badly done !
+        # FIXME: badly done !
         x_af = 0
         y_af = 0
-
-        ptr = 0
         for a_guy in self.guys:
             if self.run :
-                ptr +=1
-                # notifying the Observers
-                self.notify_progress("Processing picture", ptr, self.number_guys())
-
                 (xc, yc) = a_guy.resized_center()
                 (inx, iny) = a_guy.resized_dims()
                         
@@ -352,21 +301,13 @@ class FaceMovie(object, Observable, Observer):
         Calculates smallest output image that can be used to avoid adding black borders on image
         It will later be used to create the final image. 
         """
-        # TODO: badly done !
+        # FIXME: badly done !
         ht = 1000000 # space left above eyes
         hb = 1000000 # space left beneath eyes
         wl = 1000000 # space left left of eyes
         wr = 1000000 # space left right of eyes
-
-        tr = 0
-
-        ptr = 0
         for a_guy in self.guys:
             if self.run:
-                ptr +=1
-                # notifying the Observers
-                self.notify_progress("Processing picture", ptr, self.number_guys())
-
                 (xc, yc) = a_guy.resized_center()
                 (inx, iny) = a_guy.resized_dims()            
                 
@@ -426,8 +367,6 @@ class FaceMovie(object, Observable, Observer):
         for a_guy in self.guys:
             if self.run:
                 ii += 1 
-                self.notify_progress("Saving frame", ii, self.number_guys())
-
                 self.console_logger.info("Saving frame %d / %d" %(ii, self.number_guys()) )
                 self.my_logger.info("Saving frame %d / %d" %(ii, self.number_guys()) )             
                 out_im = self.prepare_image(a_guy)
